@@ -11,6 +11,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import socket
+
 from oslo_config import cfg
 
 from ironic_inspector.common.i18n import _
@@ -23,6 +25,14 @@ _OPTS = [
     cfg.PortOpt('listen_port',
                 default=5050,
                 help=_('Port to listen on.')),
+    cfg.StrOpt('host',
+               default=socket.getfqdn(),
+               sample_default='localhost',
+               help=_('Name of this node. This can be an opaque identifier. '
+                      'It is not necessarily a hostname, FQDN, or IP address. '
+                      'However, the node name must be valid within '
+                      'an AMQP key, and if using ZeroMQ, a valid '
+                      'hostname, FQDN, or IP address.')),
     cfg.StrOpt('auth_strategy',
                default='keystone',
                choices=('keystone', 'noauth'),
@@ -31,18 +41,8 @@ _OPTS = [
                       'options. "noauth" will disable all authentication.')),
     cfg.IntOpt('timeout',
                default=3600,
-               # We're using timedelta which can overflow if somebody sets this
-               # too high, so limit to a sane value of 10 years.
-               max=315576000,
                help=_('Timeout after which introspection is considered '
                       'failed, set to 0 to disable.')),
-    cfg.IntOpt('node_status_keep_time',
-               default=0,
-               help=_('For how much time (in seconds) to keep status '
-                      'information about nodes after introspection was '
-                      'finished for them. Set to 0 (the default) '
-                      'to disable the timeout.'),
-               deprecated_for_removal=True),
     cfg.IntOpt('clean_up_period',
                default=60,
                help=_('Amount of time in seconds, after which repeat clean up '
@@ -52,9 +52,15 @@ _OPTS = [
                 help=_('SSL Enabled/Disabled')),
     cfg.StrOpt('ssl_cert_path',
                default='',
+               deprecated_for_removal=True,
+               deprecated_reason=_('This option will be superseded by '
+                                   '[ssl]cert_file.'),
                help=_('Path to SSL certificate')),
     cfg.StrOpt('ssl_key_path',
                default='',
+               deprecated_for_removal=True,
+               deprecated_reason=_('This option will be superseded by '
+                                   '[ssl]key_file.'),
                help=_('Path to SSL key')),
     cfg.IntOpt('max_concurrency',
                default=1000, min=2,
@@ -72,7 +78,13 @@ _OPTS = [
                help=_('Path to the rootwrap configuration file to use for '
                       'running commands as root')),
     cfg.IntOpt('api_max_limit', default=1000, min=1,
-               help=_('Limit the number of elements an API list-call returns'))
+               help=_('Limit the number of elements an API list-call '
+                      'returns')),
+    cfg.BoolOpt('can_manage_boot', default=True,
+                help=_('Whether the current installation of ironic-inspector '
+                       'can manage PXE booting of nodes. If set to False, '
+                       'the API will reject introspection requests with '
+                       'manage_boot missing or set to True.')),
 ]
 
 
