@@ -15,6 +15,7 @@ import os
 import re
 
 import flask
+from oslo_utils import strutils
 from oslo_utils import uuidutils
 import six
 import werkzeug
@@ -23,10 +24,10 @@ from ironic_inspector import api_tools
 from ironic_inspector.common import context
 from ironic_inspector.common.i18n import _
 from ironic_inspector.common import ironic as ir_utils
+from ironic_inspector.common import rpc
 from ironic_inspector.common import swift
 import ironic_inspector.conf
 from ironic_inspector.conf import opts as conf_opts
-from ironic_inspector import introspect
 from ironic_inspector import node_cache
 from ironic_inspector import process
 from ironic_inspector import rules
@@ -39,7 +40,7 @@ app = flask.Flask(__name__)
 LOG = utils.getProcessingLogger(__name__)
 
 MINIMUM_API_VERSION = (1, 0)
-CURRENT_API_VERSION = (1, 12)
+CURRENT_API_VERSION = (1, 14)
 DEFAULT_API_VERSION = CURRENT_API_VERSION
 _LOGGING_EXCLUDED_KEYS = ('logs',)
 
@@ -151,7 +152,7 @@ def api(path, is_public_api=False, rule=None, verb_to_rule_map=None,
         **flask_kwargs):
     """Decorator to wrap api methods.
 
-    Performs flask routing, exception convertion,
+    Performs flask routing, exception conversion,
     generation of oslo context for request and API access policy enforcement.
 
     :param path: flask app route path
@@ -239,8 +240,24 @@ def api_continue():
      methods=['GET', 'POST'])
 def api_introspection(node_id):
     if flask.request.method == 'POST':
-        introspect.introspect(node_id,
-                              token=flask.request.headers.get('X-Auth-Token'))
+        args = flask.request.args
+
+        manage_boot = args.get('manage_boot', 'True')
+        try:
+            manage_boot = strutils.bool_from_string(manage_boot, strict=True)
+        except ValueError:
+            raise utils.Error(_('Invalid boolean value for manage_boot: %s') %
+                              manage_boot, code=400)
+
+        if manage_boot and not CONF.can_manage_boot:
+            raise utils.Error(_('Managed boot is requested, but this '
+                                'installation cannot manage boot ('
+                                '(can_manage_boot set to False)'),
+                              code=400)
+        client = rpc.get_client()
+        client.call({}, 'do_introspection', node_id=node_id,
+                    manage_boot=manage_boot,
+                    token=flask.request.headers.get('X-Auth-Token'))
         return '', 202
     else:
         node_info = node_cache.get_node(node_id)
@@ -263,7 +280,9 @@ def api_introspection_statuses():
 @api('/v1/introspection/<node_id>/abort', rule="introspection:abort",
      methods=['POST'])
 def api_introspection_abort(node_id):
-    introspect.abort(node_id, token=flask.request.headers.get('X-Auth-Token'))
+    client = rpc.get_client()
+    client.call({}, 'do_abort', node_id=node_id,
+                token=flask.request.headers.get('X-Auth-Token'))
     return '', 202
 
 
@@ -291,7 +310,8 @@ def api_introspection_reapply(node_id):
                                 'supported yet'), code=400)
 
     if CONF.processing.store_data == 'swift':
-        process.reapply(node_id)
+        client = rpc.get_client()
+        client.call({}, 'do_reapply', node_id=node_id)
         return '', 202
     else:
         return error_response(_('Inspector is not configured to store'
