@@ -18,7 +18,6 @@ import contextlib
 import copy
 import datetime
 import json
-import operator
 
 from automaton import exceptions as automaton_errors
 from ironicclient import exceptions
@@ -31,6 +30,7 @@ from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import six
 from sqlalchemy.orm import exc as orm_errors
+from sqlalchemy import text
 
 from ironic_inspector.common.i18n import _
 from ironic_inspector.common import ironic as ir_utils
@@ -470,6 +470,28 @@ class NodeInfo(object):
             ironic=ironic,
             capabilities=ir_utils.dict_to_capabilities(existing))
 
+    def add_trait(self, trait, ironic=None):
+        """Add a trait to the node.
+
+        :param trait: trait to add
+        :param ironic: Ironic client to use instead of self.ironic
+        """
+        ironic = ironic or self.ironic
+        ironic.node.add_trait(self.uuid, trait)
+
+    def remove_trait(self, trait, ironic=None):
+        """Remove a trait from the node.
+
+        :param trait: trait to add
+        :param ironic: Ironic client to use instead of self.ironic
+        """
+        ironic = ironic or self.ironic
+        try:
+            ironic.node.remove_trait(self.uuid, trait)
+        except exceptions.NotFound:
+            LOG.debug('Trait %s is not set, cannot remove', trait,
+                      node_info=self)
+
     def delete_port(self, port, ironic=None):
         """Delete port.
 
@@ -817,11 +839,14 @@ def find_node(**attributes):
 
         LOG.debug('Trying to use %s of value %s for node look up',
                   name, value)
-        query = db.model_query(db.Attribute.node_uuid)
-        pairs = [(db.Attribute.name == name) &
-                 (db.Attribute.value == v) for v in value]
-        query = query.filter(six.moves.reduce(operator.or_, pairs))
-        found.update(row.node_uuid for row in query.distinct().all())
+        value_list = []
+        for v in value:
+            value_list.append("name='%s' AND value='%s'" % (name, v))
+        stmt = ('select distinct node_uuid from attributes where ' +
+                ' OR '.join(value_list))
+        rows = (db.model_query(db.Attribute.node_uuid).from_statement(
+            text(stmt)).all())
+        found.update(row.node_uuid for row in rows)
 
     if not found:
         raise utils.NotFoundInCacheError(_(
@@ -871,19 +896,10 @@ def find_node(**attributes):
 def clean_up():
     """Clean up the cache.
 
-    * Finish introspection for timed out nodes.
-    * Drop outdated node status information.
+    Finish introspection for timed out nodes.
 
     :return: list of timed out node UUID's
     """
-    if CONF.node_status_keep_time > 0:
-        status_keep_threshold = (timeutils.utcnow() - datetime.timedelta(
-                                 seconds=CONF.node_status_keep_time))
-        with db.ensure_transaction() as session:
-            db.model_query(db.Node, session=session).filter(
-                db.Node.finished_at.isnot(None),
-                db.Node.finished_at < status_keep_threshold).delete()
-
     timeout = CONF.timeout
     if timeout <= 0:
         return []
