@@ -315,11 +315,6 @@ class TestNodeCacheFind(test_base.NodeTest):
         self.assertRaises(utils.Error, node_cache.find_node,
                           bmc_address='1.2.3.4')
 
-    def test_input_filtering(self):
-        self.assertRaises(utils.NotFoundInCacheError,
-                          node_cache.find_node,
-                          bmc_address="' OR ''='")
-
 
 class TestNodeCacheCleanUp(test_base.NodeTest):
     def setUp(self):
@@ -418,30 +413,6 @@ class TestNodeCacheCleanUp(test_base.NodeTest):
                 [(istate.States.error, current_time, 'Introspection timeout')],
                 res)
 
-    def test_old_status(self):
-        CONF.set_override('node_status_keep_time', 42)
-        session = db.get_writer_session()
-        with session.begin():
-            db.model_query(db.Node).update(
-                {'finished_at': (datetime.datetime.utcnow() -
-                                 datetime.timedelta(seconds=100))})
-
-        self.assertEqual([], node_cache.clean_up())
-
-        self.assertEqual([], db.model_query(db.Node).all())
-
-    def test_old_status_disabled(self):
-        # Status clean up is disabled by default
-        session = db.get_writer_session()
-        with session.begin():
-            db.model_query(db.Node).update(
-                {'finished_at': (datetime.datetime.utcnow() -
-                                 datetime.timedelta(days=10000))})
-
-        self.assertEqual([], node_cache.clean_up())
-
-        self.assertNotEqual([], db.model_query(db.Node).all())
-
 
 class TestNodeCacheGetNode(test_base.NodeTest):
     def test_ok(self):
